@@ -75,4 +75,13 @@ test_that("Returning meta data",{
   expect_error(con_error_msg(res1, "dummy message"), "dummy message")
   expect_equal(name1, list("dbms.name" = "default", "table" = "table1"))
   expect_equal(name2, list("dbms.name" = "mydatabase", "table" = "table1"))
-})
\ No newline at end of file
+})
+
+test_that("test connection when timezone is NULL", {
+  skip_if_no_boto()
+  skip_if_no_env()
+  
+  con <- dbConnect(athena(), timezone = NULL)
+  
+  expect_equal(con@info$timezone, "UTC")
+})
